<?php
  
// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
	echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
	exit;
}
  
// add menu under woocommerce
add_action('admin_menu', 'variations_table_menu_addition', 100);
function variations_table_menu_addition() {
  add_submenu_page( 'woocommerce', 'Variations Table', 'Variations Table', 'manage_options', 'variationstable', 'vartable_options' );
  add_action( 'admin_init', 'vartable_register_settings' );
}

function fields_func() {
  $fields_array = array(
    'vartable_disabled' => __('Disable Globally', 'vartable'),
    'vartable_categories_exc' => __('Categories Exclusion', 'vartable'),
    'vartable_sku' => __('SKU', 'vartable'),
    'vartable_thumb' => __('Thumbnail', 'vartable'),
    'vartable_thumb_size' => __('Thumbnail Size', 'vartable'),
    'vartable_stock' => __('Stock', 'vartable'),
    'vartable_in_stock_text' => __('In Stock Text', 'vartable'),
    'vartable_out_stock_text' => __('Out of Stock Text', 'vartable'),
    'vartable_low_stock_text' => __('Low Stock Text', 'vartable'),
    'vartable_low_stock_thresh' => __('Low Stock Threshold', 'vartable'),
    'vartable_hide_zero' => __('Hide zero priced variations', 'vartable'),
    'vartable_price' => __('Price', 'vartable'),
    'vartable_hide_zero' => __('Hide Zero Priced Variations', 'vartable'),
    'vartable_offer' => __('Offer Image', 'vartable'),
    'vartable_image' => __('Offer Image File', 'vartable'),
    'vartable_cart' => __('Add to Cart Button', 'vartable'),
    'vartable_globalcart' => __('Global Add to Cart Checkbox', 'vartable'),
    'vartable_qty' => __('Quantity', 'vartable'),
    'vartable_default_qty' => __('Default Quantity', 'vartable'),
    'vartable_qty_control' => __('Display Quantity Controls ( - / + buttons)', 'vartable'),
    'vartable_wishlist' => __('Whishlist', 'vartable'),
    'vartable_gift' => __('Gift Wrap', 'vartable'),
    'vartable_order' => __('Columns Order', 'vartable'),
    'vartable_ajax' => __('Enable Ajax Add to Cart', 'vartable'),
    'vartable_desc' => __('Description', 'vartable'),
    'vartable_head' => __('Table Head', 'vartable'),
    'vartable_customhead' => __('Custom Table Head', 'vartable'),
    'vartable_sorting' => __('Enable Sorting', 'vartable')
  );
  
  return (apply_filters( 'vartable_fields_func_filter', $fields_array));
}

// register settings
function vartable_register_settings(){
  $fields = fields_func();
  
  foreach($fields as $field => $fieldtext) {
    register_setting( 'vartable_group', $field ); 
  }
}


function vartable_options() {
  ?>
  <div class="wrap">
    <h2><?php _e('Variations Table Grid Settings', 'vartable'); ?></h2>
    
  <form method="post" action="options.php">
        <?php settings_fields( 'vartable_group' ); ?>
        <?php do_settings_sections( 'vartable_group' ); ?>
        <div class="fieldwrap">
        <p><?php submit_button(__('Save Changes')); ?></p>
        </div>
        <?php
                    
          
        $fields = fields_func();

        foreach($fields as $field => $fieldtext) {
          ${$field}  = get_option($field);
        }

        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_disabled">'. __('Disable globally', 'vartable') .'</label>
          <select name="vartable_disabled" id="vartable_disabled">
            <option value="1" '. ($vartable_disabled == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_disabled == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        
        // categories        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_categories_exc">'. __('Disable in Categories', 'vartable') .'</label>
          <select multiple name="vartable_categories_exc[]" id="vartable_categories_exc">
          '. 	woovartables_get_all_categories( $vartable_categories_exc ) .'
          </select>
        </div>
          <hr />
        ';
        
        
        // columns
        echo '<h4>'. __('Enable / Disable Columns', 'vartable') .'</h4>';
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_sku">'. __('Display SKU', 'vartable') .'</label>
          <select name="vartable_sku" id="vartable_sku">
            <option value="1" '. ($vartable_sku == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_sku == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
         echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_thumb">'. __('Display Thumbnail', 'vartable') .'</label>
          <select name="vartable_thumb" id="vartable_thumb">
            <option value="1" '. ($vartable_thumb == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_thumb == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_thumb_size">'. __('Thumbnail Width in Pixels', 'vartable') .'</label>
          <input type="text" name="vartable_thumb_size" id="vartable_thumb_size" value="'. $vartable_thumb_size .'">
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_stock">'. __('Display Stock', 'vartable') .'</label>
          <select name="vartable_stock" id="vartable_stock">
            <option value="1" '. ($vartable_stock == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_stock == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
          
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_in_stock_text">'. __('In Stock Text', 'vartable') .'</label>
          <input type="text" name="vartable_in_stock_text" id="vartable_in_stock_text" value="'. $vartable_in_stock_text .'">
          <small>'. __('Please use %n to display the quantity of the stock left on the above field, eg: "Just %n left"', 'vartable') .'</small>
        </div>
          <hr />
        ';
          
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_out_stock_text">'. __('Out of Stock Text', 'vartable') .'</label>
          <input type="text" name="vartable_out_stock_text" id="vartable_out_stock_text" value="'. $vartable_out_stock_text .'">
        </div>
          <hr />
        ';
          
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_low_stock_text">'. __('Low Stock Text', 'vartable') .'</label>
          <input type="text" name="vartable_low_stock_text" id="vartable_low_stock_text" value="'. $vartable_low_stock_text .'">
        </div>
          <hr />
        ';
          
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_low_stock_thresh">'. __('Low Stock Threshold', 'vartable') .'</label>
          <input type="number" name="vartable_low_stock_thresh" id="vartable_low_stock_thresh" value="'. $vartable_low_stock_thresh .'">
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_hide_zero">'. __('Hide Zero Priced Variations', 'vartable') .'</label>
          <select name="vartable_hide_zero" id="vartable_hide_zero">
            <option value="1" '. ($vartable_hide_zero == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_hide_zero == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_price">'. __('Display Price', 'vartable') .'</label>
          <select name="vartable_price" id="vartable_price">
            <option value="1" '. ($vartable_price == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_price == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_qty">'. __('Display Quantity Field', 'vartable') .'</label>
          <select name="vartable_qty" id="vartable_qty">
            <option value="1" '. ($vartable_qty == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_qty == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_default_qty">'. __('Default Quantity Value', 'vartable') .'</label>
          <input type="number" name="vartable_default_qty" id="vartable_default_qty" value="'. $vartable_default_qty .'" min="0">
        </div>
          <hr />
        ';
        
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_qty_control">'. __('Display Quantity Controls', 'vartable') .'</label>
          <select name="vartable_qty_control" id="vartable_qty_control">
            <option value="1" '. ($vartable_qty_control == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_qty_control == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_cart">'. __('Display Add To Cart', 'vartable') .'</label>
          <select name="vartable_cart" id="vartable_cart">
            <option value="1" '. ($vartable_cart == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_cart == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_globalcart">'. __('Display Global Add To Cart', 'vartable') .'</label>
          <select name="vartable_globalcart" id="vartable_globalcart">
            <option value="1" '. ($vartable_globalcart == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_globalcart == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';

        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_wishlist">'. __('Display Wishlist', 'vartable') .'</label>
          <select name="vartable_wishlist" id="vartable_wishlist">
            <option value="1" '. ($vartable_wishlist == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_wishlist == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';

        if (class_exists('WC_Product_Gift_Wrap')) {
          echo '
          <div class="fieldwrap">
            <label class="vm_label" for="vartable_gift">'. __('Display Gift Wrap Option', 'vartable') .'</label>
            <select name="vartable_gift" id="vartable_gift">
              <option value="1" '. ($vartable_gift == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
              <option value="0" '. ($vartable_gift == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
            </select>
          </div>
            <hr />
          ';
        }
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_offer">'. __('Display Image', 'vartable') .'</label>
          <select name="vartable_offer" id="vartable_offer">
            <option value="1" '. ($vartable_offer == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_offer == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
          <div class="fieldwrap">
            <label class="vm_label" for="vartable_image">'. __('Add Image', 'vartable') .'</label>';
            spyros_media_upload('vartable_image', $vartable_image);
        echo '</div>
          <hr />
        ';
        
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_desc">'. __('Display Description', 'vartable') .'</label>
          <select name="vartable_desc" id="vartable_desc">
            <option value="1" '. ($vartable_desc == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_desc == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_head">'. __('Display Table Head', 'vartable') .'</label>
          <select name="vartable_head" id="vartable_head">
            <option value="1" '. ($vartable_head == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_head == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_customhead">'. __('Custom Table Head', 'vartable') .'</label>
          <textarea name="vartable_customhead" id="vartable_customhead">'. $vartable_customhead .'</textarea>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_sorting">'. __('Enable Sorting', 'vartable') .'</label> 
          <small>'. __('It will have strange results if you will also add description per variation', 'vartable') .'</small>
          <select name="vartable_sorting" id="vartable_sorting">
            <option value="0" '. ($vartable_sorting == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
            <option value="1" '. ($vartable_sorting == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_ajax">'. __('Enable AJAX', 'vartable') .'</label>
          <small>'. __('Enabling this will disable the stock quantity check when adding to cart via the plugin', 'vartable') .'</small>
          <select name="vartable_ajax" id="vartable_ajax">
            <option value="1" '. ($vartable_ajax == 1 ? 'selected="selected"' : '') .'>'. __('Yes', 'vartable') .'</option>
            <option value="0" '. ($vartable_ajax == 0 ? 'selected="selected"' : '') .'>'. __('No', 'vartable') .'</option>
          </select>
        </div>
          <hr />
        ';
        
        
        $orderfields = fields_func();
        $orderfields['vartable_variations'] = __('Variations', 'vartable');
        if (!empty($vartable_order)) { $orderfields = array_merge($vartable_order, $orderfields); }
        // these fields should not be sortable // exclude
        $notsoratble = array('vartable_default_qty', 'vartable_qty_control', 'vartable_disabled', 'vartable_categories_exc', 'vartable_thumb_size', 'vartable_in_stock_text', 'vartable_out_stock_text', 'vartable_low_stock_text', 'vartable_low_stock_thresh', 'vartable_image', 'vartable_order', 'vartable_ajax', 'vartable_desc', 'vartable_head', 'vartable_customhead', 'vartable_responsive', 'vartable_sorting', 'vartable_hide_zero');
        
        echo '
        <div class="fieldwrap">
          <label class="vm_label" for="vartable_order">'. __('Order Columns', 'vartable') .'</label>
          <small>'. __('Please drag and drop the below list elements to order the columns of the table', 'vartable') .'</small>
          <ul id="colsort">
        ';
        foreach($orderfields as $field => $fieldtext) {
          if (!in_array($field, $notsoratble)) {
            echo '<li>&#8597; <input type="hidden" name="vartable_order['. $field .']" value="'. $fieldtext .'" />'. $fieldtext .'</li>';
          }
        }
        echo '
          </ul>
        </div>';        
        
          
    ?>
    <div class="fieldwrap">
    <p><?php submit_button(__('Save Changes')); ?></p>
    </div>
    </form>
  </div>
  <link href="<?php echo plugins_url('select2/select2.css', __FILE__); ?>" rel="stylesheet"/>
  <script src="<?php echo plugins_url('select2/select2.min.js', __FILE__); ?>"></script>
  <style>
      .fieldwrap { width: 50%; }
      .vm_label { display: block; clear: both; margin-bottom: 7px; font-size: 18px; }
      select, input, textarea { min-width: 100%; width: 100%; }
      textarea { min-height: 400px;}
      .wooxls-updated {
        margin: 5px 0 15px;
        border-left: 4px solid #7AD03A;
        padding: 1px 12px;
        background-color: #FFF;
        -webkit-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.1);
        box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.1);
      }
      .action-buttons p { display: inline; }
      .button.button-action { background: #5CB85C; border-color: #4CAE4C; color: #ffffff; font-weight: bold; -webkit-box-shadow: none; 	-moz-box-shadow: none; box-shadow: none; }
      .button.button-action:hover { background: #449D44; border-color: #398439; color: #ffffff;  }
      .button.button-danger { background: #D9534F; border-color: #D43F3A; color: #ffffff; -webkit-box-shadow: none; 	-moz-box-shadow: none; box-shadow: none; }
      .button.button-danger:hover { background: #C9302C; border-color: #AC2925; color: #ffffff; }
      li.wooxls-item:hover, li.wooxls-item:focus { background-color: rgba(255,255,255, 0.8); }
      #colsort li { cursor: move; border-bottom: 1px solid #ffffff; margin: 0; padding: 5px; }
      #colsort li:hover { background-color: #f9f9f9; }
    </style>
    <script>
      jQuery(document).ready(function(){
        jQuery("select").select2({ width: '100%' });
        jQuery( "#colsort" ).sortable();
      });
    </script>
  <?php
}
?>